@@ -48,6 +48,7 @@ class Cluster(object):
                       see the docs for details
     default_image_id
     anti_affinity
+    anti_affinity_ratio
     management_private_key
     management_public_key
     user_keypair_id
@@ -109,6 +110,8 @@ class NodeGroup(object):
                                 where to spawn volumes
     volume_mount_prefix
     volume_type
+    boot_from_volume - If set to True, the base image will be converted to a
+                       bootable volume.
     floating_ip_pool - Floating IP Pool name used to assign Floating IPs to
                        instances in this Node Group
     security_groups - List of security groups for instances in this Node Group
@@ -230,6 +233,7 @@ class NodeGroupTemplate(object):
     volumes_availability_zone
     volume_mount_prefix
     volume_type
+    boot_from_volume
     floating_ip_pool
     security_groups
     auto_security_group
