@@ -24,6 +24,8 @@ from sahara import exceptions as ex
 from sahara.i18n import _
 from sahara.plugins import opts as plugins_base
 from sahara.service.castellan import config as castellan
+from sahara.service.edp.data_sources import opts as data_source
+from sahara.service.edp.job_binaries import opts as job_binary
 from sahara.topology import topology_helper
 from sahara.utils.notification import sender
 from sahara.utils.openstack import cinder
@@ -33,8 +35,9 @@ from sahara import version
 
 
 cli_opts = [
-    cfg.StrOpt('host', default='',
-               help='Hostname or IP address that will be used to listen on.'),
+    cfg.HostAddressOpt('host', default='0.0.0.0',
+                       help='Hostname or IP address that will be used '
+                            'to listen on.'),
     cfg.PortOpt('port', default=8386,
                 help='Port that will be used to listen on.'),
     cfg.BoolOpt('log-exchange', default=False,
@@ -68,23 +71,15 @@ networking_opts = [
                 default=True,
                 help='If set to True, Sahara will use floating IPs to '
                      'communicate with instances. To make sure that all '
-                     'instances have floating IPs assigned in Nova Network '
-                     'set "auto_assign_floating_ip=True" in nova.conf. '
-                     'If Neutron is used for networking, make sure that '
-                     'all Node Groups have "floating_ip_pool" parameter '
-                     'defined.'),
+                     'instances have floating IPs assigned, make sure '
+                     'that all Node Groups have "floating_ip_pool" '
+                     'parameter defined.'),
     cfg.StrOpt('node_domain',
                default='novalocal',
-               help="The suffix of the node's FQDN. In nova-network that is "
-                    "the dhcp_domain config parameter."),
-    cfg.BoolOpt('use_neutron',
-                default=False,
-                help="Use Neutron Networking (False indicates the use of Nova "
-                     "networking)."),
+               help="The suffix of the node's FQDN."),
     cfg.BoolOpt('use_namespaces',
                 default=False,
-                help="Use network namespaces for communication (only valid to "
-                     "use in conjunction with use_neutron=True)."),
+                help="Use network namespaces for communication."),
     cfg.BoolOpt('use_rootwrap',
                 default=False,
                 help="Use rootwrap facility to allow non-root users to run "
@@ -108,6 +103,20 @@ dns_opts = [
                      "This is required if 'use_designate' is True")
 ]
 
+accessible_ip_opts = [
+    cfg.IPOpt('identity_ip_accessible',
+              default=None,
+              help='IP address of Keystone endpoint, accessible by tenant'
+                   ' machines. If not set, the results of the DNS lookup'
+                   ' performed where Sahara services are running will be'
+                   ' used.'),
+    cfg.IPOpt('object_store_ip_accessible',
+              default=None,
+              help='IP address of Swift endpoint, accessible by tenant'
+                   ' machines. If not set, the results of the DNS lookup'
+                   ' performed where Sahara services are running will be'
+                   ' used.'),
+]
 
 CONF = cfg.CONF
 CONF.register_cli_opts(cli_opts)
@@ -115,24 +124,20 @@ CONF.register_opts(networking_opts)
 CONF.register_opts(edp_opts)
 CONF.register_opts(db_opts)
 CONF.register_opts(dns_opts)
+CONF.register_opts(accessible_ip_opts)
 
 log.register_options(CONF)
 
-log.set_defaults(default_log_levels=[
-    'amqplib=WARN',
-    'qpid.messaging=INFO',
+sahara_default_log_levels = [
     'stevedore=INFO',
     'eventlet.wsgi.server=WARN',
-    'sqlalchemy=WARN',
-    'boto=WARN',
-    'suds=INFO',
-    'keystone=INFO',
     'paramiko=WARN',
     'requests=WARN',
-    'iso8601=WARN',
-    'oslo_messaging=INFO',
     'neutronclient=INFO',
-])
+]
+
+log.set_defaults(
+    default_log_levels=log.get_default_log_levels()+sahara_default_log_levels)
 
 
 def list_opts():
@@ -151,7 +156,9 @@ def list_opts():
     from sahara.swift import swift_helper
     from sahara.utils import cluster_progress_ops as cpo
     from sahara.utils.openstack import base
+    from sahara.utils.openstack import glance
     from sahara.utils.openstack import heat
+    from sahara.utils.openstack import manila
     from sahara.utils.openstack import neutron
     from sahara.utils.openstack import nova
     from sahara.utils.openstack import swift
@@ -166,6 +173,7 @@ def list_opts():
                          networking_opts,
                          dns_opts,
                          db_opts,
+                         accessible_ip_opts,
                          plugins_base.opts,
                          topology_helper.opts,
                          keystone.opts,
@@ -180,15 +188,21 @@ def list_opts():
                          heat_engine.heat_engine_opts,
                          templates.heat_engine_opts,
                          ssh_remote.ssh_config_options,
-                         castellan.opts)),
+                         castellan.opts,
+                         data_source.opts,
+                         job_binary.opts)),
         (poll_utils.timeouts.name,
          itertools.chain(poll_utils.timeouts_opts)),
         (api.conductor_group.name,
          itertools.chain(api.conductor_opts)),
         (cinder.cinder_group.name,
          itertools.chain(cinder.opts)),
+        (glance.glance_group.name,
+         itertools.chain(glance.opts)),
         (heat.heat_group.name,
          itertools.chain(heat.opts)),
+        (manila.manila_group.name,
+         itertools.chain(manila.opts)),
         (neutron.neutron_group.name,
          itertools.chain(neutron.opts)),
         (nova.nova_group.name,
@@ -197,6 +211,8 @@ def list_opts():
          itertools.chain(swift.opts)),
         (keystone.keystone_group.name,
          itertools.chain(keystone.ssl_opts)),
+        (keystone.trustee_group.name,
+         itertools.chain(keystone.trustee_opts)),
         (base.retries.name,
          itertools.chain(base.opts)),
         (swift_helper.public_endpoint_cert_group.name,
@@ -216,15 +232,3 @@ def parse_configs(conf_files=None):
         raise ex.ConfigurationError(
             _("Option '%(option)s' is required for config group '%(group)s'") %
             {'option': roe.opt_name, 'group': roe.group.name})
-    validate_configs()
-
-
-def validate_network_configs():
-    if CONF.use_namespaces and not CONF.use_neutron:
-        raise ex.ConfigurationError(
-            _('use_namespaces can not be set to "True" when use_neutron '
-              'is set to "False"'))
-
-
-def validate_configs():
-    validate_network_configs()
