@@ -23,7 +23,6 @@ from oslo_utils import uuidutils
 from sahara import conductor
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LW
 from sahara.plugins.ambari import client as ambari_client
 from sahara.plugins.ambari import common as p_common
 from sahara.plugins.ambari import configs
@@ -47,7 +46,15 @@ repo_id_map = {
     "2.4": {
         "HDP": "HDP-2.4",
         "HDP-UTILS": "HDP-UTILS-1.1.0.20"
-    }
+    },
+    "2.5": {
+        "HDP": "HDP-2.5",
+        "HDP-UTILS": "HDP-UTILS-1.1.0.20"
+    },
+    "2.6": {
+        "HDP": "HDP-2.6",
+        "HDP-UTILS": "HDP-UTILS-1.1.0.22"
+    },
 }
 
 os_type_map = {
@@ -165,8 +172,8 @@ def resolve_package_conflicts(cluster, instances=None):
                     r.execute_command(
                         "apt-get remove -y libmysql-java", run_as_root=True)
                 except Exception:
-                    LOG.warning(_LW("Can't remove libmysql-java, "
-                                    "it's probably not installed"))
+                    LOG.warning("Can't remove libmysql-java, "
+                                "it's probably not installed")
 
 
 def _prepare_ranger(cluster):
@@ -574,9 +581,9 @@ def restart_service(cluster, service_name):
 @cpo.event_wrapper(True, step=_("Remove hosts"), param=('cluster', 0))
 def remove_services_from_hosts(cluster, instances):
     for inst in instances:
-        LOG.debug("Stopping and removing processes from host %s" % inst.fqdn())
+        LOG.debug("Stopping and removing processes from host %s", inst.fqdn())
         _remove_services_from_host(cluster, inst)
-        LOG.debug("Removing the host %s" % inst.fqdn())
+        LOG.debug("Removing the host %s", inst.fqdn())
         _remove_host(cluster, inst)
 
 
@@ -584,12 +591,12 @@ def _remove_services_from_host(cluster, instance):
     with _get_ambari_client(cluster) as client:
         hdp_processes = client.list_host_processes(cluster.name, instance)
         for proc in hdp_processes:
-            LOG.debug("Stopping process %s on host %s " %
-                      (proc, instance.fqdn()))
+            LOG.debug("Stopping process %(proc)s on host %(fqdn)s ",
+                      {'proc': proc, 'fqdn': instance.fqdn()})
             client.stop_process_on_host(cluster.name, instance, proc)
 
-            LOG.debug("Removing process %s from host %s " %
-                      (proc, instance.fqdn()))
+            LOG.debug("Removing process %(proc)s from host %(fqdn)s ",
+                      {'proc': proc, 'fqdn': instance.fqdn()})
             client.remove_process_from_host(cluster.name, instance, proc)
 
     _wait_all_processes_removed(cluster, instance)
@@ -619,9 +626,9 @@ def _get_topology_data(cluster):
     if not t_helper.is_data_locality_enabled():
         return {}
 
-    LOG.warning(_LW("Node group awareness is not implemented in YARN yet "
-                    "so enable_hypervisor_awareness set to False "
-                    "explicitly"))
+    LOG.warning("Node group awareness is not implemented in YARN yet "
+                "so enable_hypervisor_awareness set to False "
+                "explicitly")
     return t_helper.generate_topology_map(cluster, is_node_awareness=False)
 
 
@@ -668,9 +675,9 @@ def _add_hadoop_swift_jar(instance, new_jar):
                     amb_code, amb_hadoop_version))
             r.execute_command("sudo cp {} {}".format(new_jar, origin_jar))
         else:
-            LOG.warning(_LW("The {jar_file} file cannot be found "
-                            "in the {dir} directory so Keystone API v3 "
-                            "is not enabled for this cluster.")
+            LOG.warning("The {jar_file} file cannot be found "
+                        "in the {dir} directory so Keystone API v3 "
+                        "is not enabled for this cluster."
                         .format(jar_file="hadoop-openstack.jar",
                                 dir="/opt"))
 
