@@ -22,7 +22,7 @@ def _root(remote, cmd, **kwargs):
 
 
 def _get_os_distrib(remote):
-    return remote.execute_command('lsb_release -is')[1].strip().lower()
+    return remote.get_os_distrib()
 
 
 def is_centos_os(remote):
@@ -67,7 +67,7 @@ def install_packages(remote, packages, timeout=1800):
     if distrib == 'ubuntu':
         cmd = 'RUNLEVEL=1 apt-get install -y %s'
     elif distrib == 'centos':
-        cmd = 'yum install %s'
+        cmd = 'yum install -y %s'
     else:
         raise ex.HadoopProvisionError(
             _("OS on image is not supported by CDH plugin"))
@@ -109,7 +109,7 @@ def add_centos_repository(r, repo_list_url, repo_name):
 
 def write_centos_repository(r, repo_content, repo_name):
     r.write_file_to('/etc/yum.repos.d/%s.repo' % repo_name,
-                    repo_content, root_as_root=True)
+                    repo_content, run_as_root=True)
 
 
 def start_mysql_server(remote):
