@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Intel Corporation
+# Copyright (c) 2016 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,51 +15,15 @@
 
 from sahara.i18n import _
 from sahara.plugins.cdh import commands as cmd
-from sahara.plugins.cdh.v5_4_0 import cloudera_utils as cu
+from sahara.plugins.cdh import deploy as common_deploy
+from sahara.plugins.cdh.v5_13_0 import cloudera_utils as cu
 from sahara.plugins import utils as gu
 from sahara.service.edp import hdfs_helper as h
 from sahara.utils import cluster_progress_ops as cpo
 
-PACKAGES = [
-    'cloudera-manager-agent',
-    'cloudera-manager-daemons',
-    'cloudera-manager-server',
-    'cloudera-manager-server-db-2',
-    'flume-ng',
-    'hadoop-hdfs-datanode',
-    'hadoop-hdfs-namenode',
-    'hadoop-hdfs-secondarynamenode',
-    'hadoop-kms'
-    'hadoop-mapreduce',
-    'hadoop-mapreduce-historyserver',
-    'hadoop-yarn-nodemanager',
-    'hadoop-yarn-resourcemanager',
-    'hbase',
-    'hbase-solr',
-    'hive-hcatalog',
-    'hive-metastore',
-    'hive-server2',
-    'hive-webhcat-server',
-    'hue',
-    'impala',
-    'impala-server',
-    'impala-state-store',
-    'impala-catalog',
-    'impala-shell',
-    'keytrustee-keyprovider',
-    'oozie',
-    'oracle-j2sdk1.7',
-    'sentry',
-    'solr-server',
-    'solr-doc',
-    'search',
-    'spark-history-server',
-    'sqoop2',
-    'unzip',
-    'zookeeper'
-]
+CU = cu.ClouderaUtilsV5130()
 
-CU = cu.ClouderaUtilsV540()
+PACKAGES = common_deploy.PACKAGES
 
 
 def configure_cluster(cluster):
@@ -72,6 +36,7 @@ def configure_cluster(cluster):
     CU.pu.start_cloudera_agents(instances)
     CU.pu.start_cloudera_manager(cluster)
     CU.update_cloudera_password(cluster)
+    CU.configure_rack_awareness(cluster)
     CU.await_agents(cluster, instances)
     CU.create_mgmt_service(cluster)
     CU.create_services(cluster)
@@ -103,8 +68,12 @@ def scale_cluster(cluster, instances):
 
     CU.pu.start_cloudera_agents(instances)
     CU.await_agents(cluster, instances)
+    CU.configure_rack_awareness(cluster)
     CU.configure_instances(instances, cluster)
     CU.update_configs(instances)
+    common_deploy.prepare_scaling_kerberized_cluster(
+        cluster, CU, instances)
+
     CU.pu.configure_swift(cluster, instances)
     _start_roles(cluster, instances)
     CU.refresh_datanodes(cluster)
@@ -186,47 +155,14 @@ def start_cluster(cluster):
 
     if CU.pu.get_stdb_rm(cluster):
         CU.enable_resourcemanager_ha(cluster)
-        # updating configs for ResourceManager role on needed nodes
+        # updating configs for ResourceManager on needed nodes
         CU.update_role_config(CU.pu.get_stdb_rm(cluster), 'YARN_STANDBYRM')
 
     _finish_cluster_starting(cluster)
 
+    common_deploy.setup_kerberos_for_cluster(cluster, CU)
+
 
 def get_open_ports(node_group):
-    ports = [9000]  # for CM agent
-
-    ports_map = {
-        'CLOUDERA_MANAGER': [7180, 7182, 7183, 7432, 7184, 8084, 8086, 10101,
-                             9997, 9996, 8087, 9998, 9999, 8085, 9995, 9994],
-        'HDFS_NAMENODE': [8020, 8022, 50070, 50470],
-        'HDFS_SECONDARYNAMENODE': [50090, 50495],
-        'HDFS_DATANODE': [50010, 1004, 50075, 1006, 50020],
-        'YARN_RESOURCEMANAGER': [8030, 8031, 8032, 8033, 8088],
-        'YARN_STANDBYRM': [8030, 8031, 8032, 8033, 8088],
-        'YARN_NODEMANAGER': [8040, 8041, 8042],
-        'YARN_JOBHISTORY': [10020, 19888],
-        'HIVE_METASTORE': [9083],
-        'HIVE_SERVER2': [10000],
-        'HUE_SERVER': [8888],
-        'OOZIE_SERVER': [11000, 11001],
-        'SPARK_YARN_HISTORY_SERVER': [18088],
-        'ZOOKEEPER_SERVER': [2181, 3181, 4181, 9010],
-        'HBASE_MASTER': [60000],
-        'HBASE_REGIONSERVER': [60020],
-        'FLUME_AGENT': [41414],
-        'SENTRY_SERVER': [8038],
-        'SOLR_SERVER': [8983, 8984],
-        'SQOOP_SERVER': [8005, 12000],
-        'KEY_VALUE_STORE_INDEXER': [],
-        'IMPALA_CATALOGSERVER': [25020, 26000],
-        'IMPALA_STATESTORE': [25010, 24000],
-        'IMPALAD': [21050, 21000, 23000, 25000, 28000, 22000],
-        'KMS': [16000, 16001],
-        'JOURNALNODE': [8480, 8481, 8485]
-    }
-
-    for process in node_group.node_processes:
-        if process in ports_map:
-            ports.extend(ports_map[process])
-
+    ports = common_deploy.get_open_ports(node_group)
     return ports
