@@ -15,7 +15,7 @@
 
 from sahara.plugins.cdh import confighints_helper as ch_helper
 from sahara.plugins.cdh import edp_engine
-from sahara.plugins.cdh.v5_7_0 import cloudera_utils as cu
+from sahara.plugins.cdh.v5_9_0 import cloudera_utils as cu
 from sahara.service.edp.oozie import engine as oozie_engine
 from sahara.utils import edp
 
@@ -24,31 +24,24 @@ class EdpOozieEngine(edp_engine.EdpOozieEngine):
 
     def __init__(self, cluster):
         super(EdpOozieEngine, self).__init__(cluster)
-        self.cloudera_utils = cu.ClouderaUtilsV570()
-
-    def get_name_node_uri(self, cluster):
-        if len(self.cloudera_utils.pu.get_jns(cluster)) > 0:
-            return 'hdfs://%s' % self.cloudera_utils.NAME_SERVICE
-        else:
-            namenode_ip = self.cloudera_utils.pu.get_namenode(cluster).fqdn()
-            return 'hdfs://%s:8020' % namenode_ip
+        self.cloudera_utils = cu.ClouderaUtilsV590()
 
     @staticmethod
     def get_possible_job_config(job_type):
         if edp.compare_job_type(job_type, edp.JOB_TYPE_HIVE):
             return {'job_config': ch_helper.get_possible_hive_config_from(
-                    'plugins/cdh/v5_7_0/resources/hive-site.xml')}
+                    'plugins/cdh/v5_9_0/resources/hive-site.xml')}
         if edp.compare_job_type(job_type,
                                 edp.JOB_TYPE_MAPREDUCE,
                                 edp.JOB_TYPE_MAPREDUCE_STREAMING):
             return {'job_config': ch_helper.get_possible_mapreduce_config_from(
-                    'plugins/cdh/v5_7_0/resources/mapred-site.xml')}
+                    'plugins/cdh/v5_9_0/resources/mapred-site.xml')}
         if edp.compare_job_type(job_type, edp.JOB_TYPE_PIG):
             return {'job_config': ch_helper.get_possible_pig_config_from(
-                    'plugins/cdh/v5_7_0/resources/mapred-site.xml')}
+                    'plugins/cdh/v5_9_0/resources/mapred-site.xml')}
         return oozie_engine.OozieJobEngine.get_possible_job_config(job_type)
 
 
 class EdpSparkEngine(edp_engine.EdpSparkEngine):
 
-    edp_base_version = "5.7.0"
+    edp_base_version = "5.9.0"
