@@ -21,16 +21,15 @@ from oslo_utils import timeutils
 
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LI
 import sahara.plugins.exceptions as ex
 import sahara.plugins.mapr.abstract.node_manager as s
 import sahara.plugins.mapr.services.management.management as mng
 import sahara.plugins.mapr.services.maprfs.maprfs as mfs
-
+import sahara.plugins.mapr.util.event_log as el
+from sahara.utils import cluster_progress_ops as cpo
 
 LOG = logging.getLogger(__name__)
 
-
 GET_SERVER_ID_CMD = ('maprcli node list -json -filter [ip==%s] -columns id'
                      ' | grep id | grep -o \'[0-9]*\'')
 NODE_LIST_CMD = 'maprcli node list -json'
@@ -57,21 +56,22 @@ class BaseNodeManager(s.AbstractNodeManager):
                     ec, out = r.execute_command(command, run_as_root=True)
                     command = MOVE_NODE_CMD % out.strip()
                     cldb_remote.execute_command(command, run_as_root=True)
-        LOG.info(_LI("Nodes successfully moved"))
+        LOG.info("Nodes successfully moved")
 
-    def remove_nodes(self, c_context, instances):
+    def remove_nodes(self, cluster_context, instances):
         LOG.debug("Removing nodes from cluster")
-        cldb_instances = self._get_cldb_instances(c_context, instances)
+        cldb_instances = self._get_cldb_instances(cluster_context, instances)
         with random.choice(cldb_instances).remote() as cldb_remote:
             for instance in instances:
                 args = {
                     'ip': instance.internal_ip,
                     'nodes': instance.fqdn(),
-                    'zookeepers': c_context.get_zookeeper_nodes_ip_with_port(),
+                    'zookeepers':
+                        cluster_context.get_zookeeper_nodes_ip_with_port(),
                 }
                 command = REMOVE_NODE_CMD % args
                 cldb_remote.execute_command(command, run_as_root=True)
-        LOG.info(_LI("Nodes successfully removed"))
+        LOG.info("Nodes successfully removed")
 
     def start(self, cluster_context, instances=None):
         instances = instances or cluster_context.get_instances()
@@ -80,15 +80,27 @@ class BaseNodeManager(s.AbstractNodeManager):
         others = filter(
             lambda i: not cluster_context.check_for_process(i, mfs.CLDB),
             instances)
+        cpo.add_provisioning_step(cluster_context.cluster.id,
+                                  _("Start ZooKeepers nodes"), len(zookeepers))
         self._start_zk_nodes(zookeepers)
+        cpo.add_provisioning_step(cluster_context.cluster.id,
+                                  _("Start CLDB nodes"), len(cldbs))
         self._start_cldb_nodes(cldbs)
-        self._start_non_cldb_nodes(others)
+        if others:
+            cpo.add_provisioning_step(cluster_context.cluster.id,
+                                      _("Start non-CLDB nodes"),
+                                      len(list(others)))
+            self._start_non_cldb_nodes(others)
         self._await_cldb(cluster_context, instances)
 
     def stop(self, cluster_context, instances=None):
         instances = instances or cluster_context.get_instances()
         zookeepers = cluster_context.filter_instances(instances, mng.ZOOKEEPER)
+        cpo.add_provisioning_step(cluster_context.cluster.id,
+                                  _("Stop ZooKeepers nodes"), len(zookeepers))
         self._stop_zk_nodes(zookeepers)
+        cpo.add_provisioning_step(cluster_context.cluster.id,
+                                  _("Stop Warden nodes"), len(instances))
         self._stop_warden_on_nodes(instances)
 
     def _await_cldb(self, cluster_context, instances=None, timeout=600):
@@ -109,11 +121,11 @@ class BaseNodeManager(s.AbstractNodeManager):
                     ips = [n['ip'] for n in resp['data']]
                     retry_count += 1
                     for i in instances:
-                        if (i.internal_ip not in ips
-                                and retry_count > DEFAULT_RETRY_COUNT):
-                            raise ex.HadoopProvisionError(_(
-                                "Node failed to connect to CLDB: %s") %
-                                i.internal_ip)
+                        if (i.internal_ip not in ips and
+                                (retry_count > DEFAULT_RETRY_COUNT)):
+                            msg = _("Node failed to connect to CLDB: %s"
+                                    ) % i.internal_ip
+                            raise ex.HadoopProvisionError(msg)
                     break
                 else:
                     context.sleep(DELAY)
@@ -135,17 +147,17 @@ class BaseNodeManager(s.AbstractNodeManager):
     def _start_zk_nodes(self, instances):
         LOG.debug('Starting ZooKeeper nodes')
         self._start_nodes(instances, mng.ZOOKEEPER.ui_name)
-        LOG.info(_LI('ZooKeeper nodes successfully started'))
+        LOG.info('ZooKeeper nodes successfully started')
 
     def _start_cldb_nodes(self, instances):
         LOG.debug('Starting CLDB nodes')
         self._start_nodes(instances, WARDEN_SERVICE)
-        LOG.info(_LI('CLDB nodes successfully started'))
+        LOG.info('CLDB nodes successfully started')
 
     def _start_non_cldb_nodes(self, instances):
         LOG.debug('Starting non-control nodes')
         self._start_nodes(instances, WARDEN_SERVICE)
-        LOG.info(_LI('Non-control nodes successfully started'))
+        LOG.info('Non-control nodes successfully started')
 
     def _stop_zk_nodes(self, instances):
         self._stop_nodes(instances, mng.ZOOKEEPER.ui_name)
@@ -164,15 +176,18 @@ class BaseNodeManager(s.AbstractNodeManager):
                     command=cmd, ip=instance.internal_ip))
             r.execute_command(cmd, run_as_root=True)
 
+    @el.provision_event(instance_reference=1)
     def _start_service(self, instance, service):
         return self._do_service_action(instance, service, START)
 
+    @el.provision_event(instance_reference=1)
     def _stop_service(self, instance, service):
         return self._do_service_action(instance, service, STOP)
 
-    def _get_cldb_instances(self, c_context, instances):
-        current = self._get_current_cluster_instances(c_context, instances)
-        return c_context.filter_instances(current, mfs.CLDB)
+    def _get_cldb_instances(self, cluster_context, instances):
+        current = self._get_current_cluster_instances(cluster_context,
+                                                      instances)
+        return cluster_context.filter_instances(current, mfs.CLDB)
 
     @staticmethod
     def await_no_heartbeat():
