@@ -25,7 +25,7 @@ from sahara.plugins.mapr.util import event_log as el
 from sahara.plugins.mapr.util import general as g
 from sahara.plugins.mapr.util import service_utils as su
 import sahara.plugins.provisioning as p
-from sahara.utils import files as files
+from sahara.utils import files
 
 LOG = logging.getLogger(__name__)
 
@@ -93,8 +93,8 @@ class Service(object):
             g.execute_on_instances(_instances,
                                    self._install_packages_on_instance,
                                    _context)
-
-        _install(cluster_context, service_instances)
+        if service_instances:
+            _install(cluster_context, service_instances)
 
     @el.provision_event(instance_reference=1)
     def _install_packages_on_instance(self, instance, cluster_context):
@@ -118,7 +118,7 @@ class Service(object):
     def _set_service_dir_owner(self, cluster_context, instances):
         service_instances = cluster_context.filter_instances(instances,
                                                              service=self)
-        LOG.debug("Changing %s service dir owner" % self.ui_name)
+        LOG.debug("Changing %s service dir owner", self.ui_name)
         for instance in service_instances:
             cmd.chown(instance, 'mapr:mapr', self.service_dir(cluster_context))
 
