@@ -14,9 +14,12 @@ if [ ! -f /etc/init.d/mysql* ]; then
                                                         /etc/mysql/my.cnf
         sudo service mysql restart
     elif [[ $1 == *"CentOS"* ]] || \
-        [[ $1 == *"Red Hat Enterprise Linux"* ]]; then
-        sudo yum install -y mysql-server
-        sudo yum install -y mysql-connector-java
+        [[ $1 == "RedHatEnterpriseServer" ]]; then
+            if [[ $2 == "7" ]]; then
+                sudo yum install -y mariadb-server
+            else
+                sudo yum install -y mysql-server
+            fi
     elif [[ $1 == *"SUSE"* ]]; then
         sudo zypper mysql-server
     else
