@@ -15,10 +15,12 @@
 from oslo_log import log as logging
 
 import sahara.context as context
+from sahara.i18n import _
 import sahara.plugins.mapr.domain.configuration_file as bcf
 import sahara.plugins.mapr.domain.node_process as np
 import sahara.plugins.mapr.domain.service as s
 import sahara.plugins.mapr.services.mysql.mysql as mysql
+import sahara.plugins.mapr.util.event_log as el
 import sahara.plugins.mapr.util.general as g
 import sahara.plugins.mapr.util.validation_utils as vu
 
@@ -103,7 +105,7 @@ class Oozie(s.Service):
 
         if oozie_service:
             symlink_cmd = (
-                'cp /usr/share/java/mysql-connector-java.jar %s' %
+                'cp /opt/mapr/lib/mysql-connector-*.jar %s' %
                 self.libext_path())
             with oozie_inst.remote() as r:
                 LOG.debug('Installing MySQL connector for Oozie')
@@ -115,9 +117,11 @@ class Oozie(s.Service):
         instances = cluster_context.filter_instances(instances, OOZIE)
         self._rebuild(cluster_context, instances)
 
+    @el.provision_event(instance_reference=1)
     @g.remote_command(1)
     def _rebuild_oozie_war(self, remote, cluster_context):
-        cmd = '%(home)s/bin/oozie-setup.sh -hadoop %(version)s' \
+        cmd = 'cp -f /opt/mapr-repository/ext-2.2.zip %(home)s/libext/ext-2.2.zip &&' \
+              ' %(home)s/bin/oozie-setup.sh -hadoop %(version)s' \
               ' /opt/mapr/hadoop/hadoop-%(version)s'
         args = {'home': self.home_dir(cluster_context),
                 'version': cluster_context.hadoop_version}
@@ -128,6 +132,7 @@ class Oozie(s.Service):
         instances = cluster_context.filter_instances(instances, OOZIE)
         self._rebuild(cluster_context, instances)
 
+    @el.provision_step(_("Rebuilt Oozie war"))
     def _rebuild(self, cluster_context, instances):
         OOZIE.stop(filter(OOZIE.is_started, instances))
         g.execute_on_instances(
@@ -161,24 +166,3 @@ class OozieV420(Oozie):
 
     def post_install(self, cluster_context, instances):
         super(OozieV420, self).post_install(cluster_context, instances)
-        self.fix_oozie_bug(cluster_context)
-
-    def fix_oozie_bug(self, cluster_context):
-        """Wrong maprfs jar bug
-
-        On some environments Oozie installation
-        process takes incorrect jar that causes failure
-        to run jobs. This is a temporary bug in Oozie and
-        is going to be fixed soon.
-        """
-
-        if cluster_context.mapr_version != '5.1.0':
-            return
-        oozie_inst = cluster_context.get_instance(OOZIE)
-        command = "sudo rm /opt/mapr/hadoop/hadoop-2.7.0/share/hadoop/kms/" \
-                  "tomcat/webapps/kms/WEB-INF/lib/maprfs-5.1.0-mapr.jar" \
-                  " && sudo ln -s /opt/mapr/lib/maprfs-5.1.0-mapr.jar" \
-                  " /opt/mapr/hadoop/hadoop-2.7.0/share/hadoop/kms/" \
-                  "tomcat/webapps/kms/WEB-INF/lib/maprfs-5.1.0-mapr.jar"
-        with oozie_inst.remote() as r:
-            r.execute_command(command, run_as_root=True)
