@@ -24,10 +24,22 @@ from sahara.utils import resources
 class ProvisioningPluginBase(plugins_base.PluginInterface):
     @plugins_base.required
     def get_versions(self):
+        """Get available plugin versions
+
+        :returns: A sequence of strings representing the versions
+
+        For example:
+            ["1.0.0", "1.0.1"]
+        """
         pass
 
     @plugins_base.required
     def get_configs(self, hadoop_version):
+        """Get default configuration for a given plugin version
+
+        :param hadoop_version: String representing a plugin version
+        :returns: A dict containing the configuration
+        """
         pass
 
     @plugins_base.required_with_default
@@ -43,6 +55,19 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
 
     @plugins_base.required
     def get_node_processes(self, hadoop_version):
+        """Get node processes of a given plugin version
+
+        :param hadoop_version: String containing a plugin version
+        :returns: A dict where the keys are the core components of the plugin
+        and the value is a sequence of node processes for that component
+
+        For example:
+        {
+            "HDFS": ["namenode", "datanode"],
+            "Spark": ["master", "slave"]
+        }
+
+        """
         pass
 
     @plugins_base.required_with_default
@@ -110,24 +135,24 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
 
     @plugins_base.optional
     def pack_image(self, hadoop_version, remote,
-                   reconcile=True, image_arguments=None):
+                   test_only=False, image_arguments=None):
         """Packs an image for registration in Glance and use by Sahara
 
         :param remote: A remote (usually of type
             sahara.cli.image_pack.api.ImageRemote) that serves as a handle to
             the image to modify. Note that this image will be modified
             in-place, not copied.
-        :param reconcile: If set to False, this method will only test to
+        :param test_only: If set to True, this method will only test to
             ensure that the image already meets the plugin's requirements.
             This can be used to test images without modification. If set to
-            True per the default, this method will modify the image if any
+            False per the default, this method will modify the image if any
             requirements are not met.
         :param image_arguments: A dict of image argument name to argument
             value.
         :raises: sahara.plugins.exceptions.ImageValidationError: If the method
-            fails to modify the image to specification (if reconcile is True),
+            fails to modify the image to specification (if test_only is False),
             or if the method finds that the image does not meet the
-            specification (if reconcile is False).
+            specification (if test_only is True).
         :raises: sahara.plugins.exceptions.ImageValidationSpecificationError:
             If the specification for image generation or validation is itself
             in error and cannot be executed without repair.
@@ -135,22 +160,22 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
         pass
 
     @plugins_base.optional
-    def validate_images(self, cluster, reconcile=True, image_arguments=None):
+    def validate_images(self, cluster, test_only=False, image_arguments=None):
         """Validates the image to be used by a cluster.
 
         :param cluster: The object handle to a cluster which has active
             instances ready to generate remote handles.
-        :param reconcile: If set to False, this method will only test to
+        :param test_only: If set to True, this method will only test to
             ensure that the image already meets the plugin's requirements.
             This can be used to test images without modification. If set to
-            True per the default, this method will modify the image if any
+            False per the default, this method will modify the image if any
             requirements are not met.
         :param image_arguments: A dict of image argument name to argument
             value.
         :raises: sahara.plugins.exceptions.ImageValidationError: If the method
-            fails to modify the image to specification (if reconcile is True),
+            fails to modify the image to specification (if test_only is False),
             or if the method finds that the image does not meet the
-            specification (if reconcile is False).
+            specification (if test_only is True).
         :raises: sahara.plugins.exceptions.ImageValidationSpecificationError:
             If the specification for image generation or validation is itself
             in error and cannot be executed without repair.
