@@ -22,7 +22,6 @@ from oslo_log import log as logging
 from sahara import conductor
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LI
 from sahara.plugins import exceptions as ex
 from sahara.plugins import provisioning as p
 from sahara.plugins import recommendations_utils as ru
@@ -61,14 +60,19 @@ class SparkProvider(p.ProvisioningPluginBase):
 
     def get_labels(self):
         default = {'enabled': {'status': True}, 'stable': {'status': True}}
+        deprecated = {'enabled': {'status': True},
+                      'deprecated': {'status': True}}
         result = {'plugin_labels': copy.deepcopy(default)}
+        stable_versions = ['2.3', '2.2']
         result['version_labels'] = {
-            version: copy.deepcopy(default) for version in self.get_versions()
+            version: copy.deepcopy(
+                default if version in stable_versions else deprecated
+                ) for version in self.get_versions()
         }
         return result
 
     def get_versions(self):
-        return ['1.6.0', '1.3.1']
+        return ['2.3', '2.2', '2.1.0', '1.6.0']
 
     def get_configs(self, hadoop_version):
         return c_helper.get_plugin_configs()
@@ -102,9 +106,13 @@ class SparkProvider(p.ProvisioningPluginBase):
         sm_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "master")])
 
-        if sm_count != 1:
+        if sm_count < 1:
             raise ex.RequiredServiceMissingException("Spark master")
 
+        if sm_count >= 2:
+            raise ex.InvalidComponentCountException("Spark master", "1",
+                                                    sm_count)
+
         sl_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "slave")])
 
@@ -136,7 +144,7 @@ class SparkProvider(p.ProvisioningPluginBase):
     def _start_spark(self, cluster, sm_instance):
         with remote.get_remote(sm_instance) as r:
             run.start_spark_master(r, self._spark_home(cluster))
-            LOG.info(_LI("Spark service has been started"))
+            LOG.info("Spark service has been started")
 
     def start_cluster(self, cluster):
         nn_instance = utils.get_instance(cluster, "namenode")
@@ -149,7 +157,7 @@ class SparkProvider(p.ProvisioningPluginBase):
         self._start_datanode_processes(dn_instances)
         run.await_datanodes(cluster)
 
-        LOG.info(_LI("Hadoop services have been started"))
+        LOG.info("Hadoop services have been started")
 
         with remote.get_remote(nn_instance) as r:
             r.execute_command("sudo -u hdfs hdfs dfs -mkdir -p /user/$USER/")
@@ -160,7 +168,7 @@ class SparkProvider(p.ProvisioningPluginBase):
         self.start_spark(cluster)
         swift_helper.install_ssl_certs(utils.get_instances(cluster))
 
-        LOG.info(_LI('Cluster has been started successfully'))
+        LOG.info('Cluster has been started successfully')
         self._set_cluster_info(cluster)
 
     def _spark_home(self, cluster):
@@ -456,7 +464,7 @@ class SparkProvider(p.ProvisioningPluginBase):
 
         swift_helper.install_ssl_certs(instances)
         run.start_spark_master(r_master, self._spark_home(cluster))
-        LOG.info(_LI("Spark master service has been restarted"))
+        LOG.info("Spark master service has been restarted")
 
     def _get_scalable_processes(self):
         return ["datanode", "slave"]
