@@ -19,7 +19,6 @@ from oslo_log import log as logging
 
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LI
 from sahara.plugins import utils as pu
 from sahara.plugins.vanilla.hadoop2 import config_helper as c_helper
 from sahara.plugins.vanilla.hadoop2 import oozie_helper
@@ -116,6 +115,46 @@ def start_spark_history_server(master):
                 sp_home, 'sbin/start-history-server.sh'))
 
 
+def start_zk_server(instances):
+    cpo.add_provisioning_step(
+        instances[0].cluster_id,
+        pu.start_process_event_message("ZooKeeper"),
+        len(instances))
+
+    with context.ThreadGroup() as tg:
+        for instance in instances:
+            with context.set_current_instance_id(instance.instance_id):
+                tg.spawn('ZK-start-processes-%s' % instance.instance_name,
+                         _start_zk_processes, instance, 'start')
+
+
+def refresh_zk_servers(cluster, to_delete_instances=None):
+    instances = vu.get_zk_servers(cluster)
+    if to_delete_instances:
+        for instance in to_delete_instances:
+            if instance in instances:
+                instances.remove(instance)
+
+    cpo.add_provisioning_step(
+        cluster.id,
+        pu.start_process_event_message("ZooKeeper"),
+        len(instances))
+
+    with context.ThreadGroup() as tg:
+        for instance in instances:
+            with context.set_current_instance_id(instance.instance_id):
+                tg.spawn('ZK-restart-processes-%s' % instance.instance_name,
+                         _start_zk_processes, instance, 'restart')
+
+
+@cpo.event_wrapper(True)
+def _start_zk_processes(instance, operation):
+    with instance.remote() as r:
+        r.execute_command(
+            'sudo su - -c "bash /opt/zookeeper/bin/zkServer.sh %s"'
+            ' hadoop' % operation)
+
+
 def format_namenode(instance):
     instance.remote().execute_command(
         'sudo su - -c "hdfs namenode -format" hadoop')
@@ -239,8 +278,10 @@ def start_hiveserver_process(pctx, instance):
                 if not oozie or instance.hostname() != oozie.hostname():
                     _start_mysql(r)
 
+                version = instance.cluster.hadoop_version
                 sql_script = files.get_file_text(
-                    'plugins/vanilla/hadoop2/resources/create_hive_db.sql'
+                    'plugins/vanilla/v{}/resources/create_hive_db.sql'.format(
+                        version.replace('.', '_'))
                 )
 
                 sql_script = sql_script.replace(
@@ -248,5 +289,5 @@ def start_hiveserver_process(pctx, instance):
                 r.write_file_to('/tmp/create_hive_db.sql', sql_script)
                 _hive_create_db(r)
                 _hive_metastore_start(r)
-                LOG.info(_LI("Hive Metastore server at {host} has been "
-                             "started").format(host=instance.hostname()))
+                LOG.info("Hive Metastore server at {host} has been "
+                         "started".format(host=instance.hostname()))
