@@ -13,25 +13,35 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import copy
 
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_serialization import jsonutils as json
 import six
 import yaml
 
 from sahara.plugins import provisioning as plugin_provisioning
 from sahara.service.heat import commons as heat_common
+from sahara.utils import cluster as cl
 from sahara.utils import general as g
 from sahara.utils.openstack import base as b
 from sahara.utils.openstack import heat as h
 from sahara.utils.openstack import neutron
+from sahara.utils.openstack import nova
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 SSH_PORT = 22
 INSTANCE_RESOURCE_NAME = "inst"
-SERVER_GROUP_PARAM_NAME = "servgroup"
+SERVER_GROUP_NAMES = "servgroups"
+AUTO_SECURITY_GROUP_PARAM_NAME = "autosecgroup"
+INTERNAL_DESIGNATE_REC = "internal_designate_record"
+INTERNAL_DESIGNATE_REV_REC = "internal_designate_reverse_record"
+EXTERNAL_DESIGNATE_REC = "external_designate_record"
+EXTERNAL_DESIGNATE_REV_REC = "external_designate_reverse_record"
+
 # TODO(vgridnev): Using insecure flag until correct way to pass certificate
 # will be invented
 WAIT_CONDITION_SCRIPT_TEMPLATE = '''
@@ -63,8 +73,16 @@ def _get_inst_name(ng):
     }
 
 
-def _get_aa_group_name(cluster):
-    return g.generate_aa_group_name(cluster.name)
+def _get_inst_domain_name(domain):
+    return {
+        "list_join": [
+            '.',
+            [{"get_attr": [INSTANCE_RESOURCE_NAME, "name"]}, domain]]
+    }
+
+
+def _get_aa_group_name(cluster, server_group_index):
+    return g.generate_aa_group_name(cluster.name, server_group_index)
 
 
 def _get_port_name(ng):
@@ -119,6 +137,10 @@ def _get_wc_waiter_name(inst_name):
     return '%s-wc-waiter' % inst_name
 
 
+def _get_index_from_inst_name(inst_name):
+    return inst_name.split('-')[-1]
+
+
 class ClusterStack(object):
     def __init__(self, cluster):
         self.cluster = cluster
@@ -131,6 +153,7 @@ class ClusterStack(object):
             "Sahara engine: {version}".format(
                 cluster=cluster.name, version=heat_common.HEAT_ENGINE_VERSION)
         )
+        self._current_sg_index = 1
 
     def _node_group_description(self, ng):
         return "{info}\nNode group {node_group}".format(
@@ -147,15 +170,16 @@ class ClusterStack(object):
                     node_group=ng.name, info=self.base_info))
 
     def add_node_group_extra(self, node_group_id, node_count,
-                             gen_userdata_func):
+                             gen_userdata_func, instances_to_delete=None):
         self.node_groups_extra[node_group_id] = {
             'node_count': node_count,
-            'gen_userdata_func': gen_userdata_func
+            'gen_userdata_func': gen_userdata_func,
+            'instances_to_delete': instances_to_delete
         }
 
-    def _get_main_template(self):
+    def _get_main_template(self, instances_to_delete=None):
         outputs = {}
-        resources = self._serialize_resources(outputs)
+        resources = self._serialize_resources(outputs, instances_to_delete)
         return yaml.safe_dump({
             "heat_template_version": heat_common.HEAT_TEMPLATE_VERSION,
             "description": self.base_info,
@@ -163,31 +187,48 @@ class ClusterStack(object):
             "outputs": outputs
         })
 
-    def instantiate(self, update_existing, disable_rollback=True):
-        main_tmpl = self._get_main_template()
-
+    def instantiate(self, update_existing, disable_rollback=True,
+                    instances_to_delete=None):
+        main_tmpl = self._get_main_template(instances_to_delete)
         kwargs = {
             'stack_name': self.cluster.stack_name,
             'timeout_mins': 180,
             'disable_rollback': disable_rollback,
             'parameters': {},
             'template': main_tmpl,
-            'files': self.files}
+            'files': self.files
+        }
 
         if CONF.heat_stack_tags:
             kwargs['tags'] = ",".join(CONF.heat_stack_tags)
 
+        log_kwargs = copy.deepcopy(kwargs)
+        log_kwargs['template'] = yaml.safe_load(log_kwargs['template'])
+        for filename in log_kwargs['files'].keys():
+            log_kwargs['files'][filename] = yaml.safe_load(
+                log_kwargs['files'][filename])
+        log_kwargs = json.dumps(log_kwargs)
+
         if not update_existing:
-            LOG.debug("Creating Heat stack with args: {args}"
-                      .format(args=kwargs))
+            LOG.debug("Creating Heat stack with args: \n{args}"
+                      .format(args=log_kwargs))
             b.execute_with_retries(h.client().stacks.create, **kwargs)
         else:
             stack = h.get_stack(self.cluster.stack_name)
             self.last_updated_time = stack.updated_time
-            LOG.debug("Updating Heat stack {stack} with args: "
-                      "{args}".format(stack=stack, args=kwargs))
+            LOG.debug("Updating Heat stack {stack} with args: \n"
+                      "{args}".format(stack=stack, args=log_kwargs))
             b.execute_with_retries(stack.update, **kwargs)
 
+    def _get_server_group_name(self):
+        index = self._current_sg_index
+        # computing server group index in round robin fashion
+        if index < self.cluster.anti_affinity_ratio:
+            self._current_sg_index = (index + 1)
+        else:
+            self._current_sg_index = 1
+        return _get_aa_group_name(self.cluster, self._current_sg_index)
+
     def _need_aa_server_group(self, node_group):
         for node_process in node_group.node_processes:
             if node_process in self.cluster.anti_affinity:
@@ -201,37 +242,67 @@ class ClusterStack(object):
         return {
             "scheduler_hints": {
                 "group": {
-                    "get_param": SERVER_GROUP_PARAM_NAME,
+                    "get_param": [SERVER_GROUP_NAMES,
+                                  {"get_param": "instance_index"}]
                 }
             }
         }
 
-    def _serialize_resources(self, outputs):
+    def _serialize_resources(self, outputs, instances_to_delete=None):
         resources = {}
 
         if self.cluster.anti_affinity:
-            resources.update(self._serialize_aa_server_group())
+            # Creating server groups equal to the anti_affinity_ratio
+            for i in range(0, self.cluster.anti_affinity_ratio):
+                resources.update(self._serialize_aa_server_group(i + 1))
 
         for ng in self.cluster.node_groups:
-            resources.update(self._serialize_ng_group(ng, outputs))
+            resources.update(self._serialize_ng_group(ng, outputs,
+                                                      instances_to_delete))
+
+        for ng in self.cluster.node_groups:
+            resources.update(self._serialize_auto_security_group(ng))
 
         return resources
 
-    def _serialize_ng_group(self, ng, outputs):
+    def _serialize_ng_group(self, ng, outputs, instances_to_delete=None):
         ng_file_name = "file://" + ng.name + ".yaml"
         self.files[ng_file_name] = self._serialize_ng_file(ng)
 
         outputs[ng.name + "-instances"] = {
             "value": {"get_attr": [ng.name, "instance"]}}
         properties = {"instance_index": "%index%"}
+
         if ng.cluster.anti_affinity:
-            properties[SERVER_GROUP_PARAM_NAME] = {
-                'get_resource': _get_aa_group_name(ng.cluster)}
+            ng_count = self.node_groups_extra[ng.id]['node_count']
+            # assuming instance_index also start from index 0
+            for i in range(0, ng_count):
+                server_group_name = self._get_server_group_name()
+                server_group_resource = {
+                    "get_resource": server_group_name
+                }
+                if SERVER_GROUP_NAMES not in properties:
+                    properties[SERVER_GROUP_NAMES] = []
+
+                properties[SERVER_GROUP_NAMES].insert(i, server_group_resource)
+
+        if ng.auto_security_group:
+            properties[AUTO_SECURITY_GROUP_PARAM_NAME] = {
+                'get_resource': g.generate_auto_security_group_name(ng)}
+
+        removal_policies = []
+        if self.node_groups_extra[ng.id]['instances_to_delete']:
+            resource_list = []
+            for name in self.node_groups_extra[ng.id]['instances_to_delete']:
+                resource_list.append(_get_index_from_inst_name(name))
+            removal_policies.append({'resource_list': resource_list})
+
         return {
             ng.name: {
                 "type": "OS::Heat::ResourceGroup",
                 "properties": {
                     "count": self.node_groups_extra[ng.id]['node_count'],
+                    "removal_policies": removal_policies,
                     "resource_def": {
                         "type": ng_file_name,
                         "properties": properties
@@ -242,8 +313,14 @@ class ClusterStack(object):
 
     def _serialize_ng_file(self, ng):
         parameters = {"instance_index": {"type": "string"}}
+
         if ng.cluster.anti_affinity:
-            parameters[SERVER_GROUP_PARAM_NAME] = {'type': "string"}
+            parameters[SERVER_GROUP_NAMES] = {"type": "comma_delimited_list",
+                                              "default": []}
+
+        if ng.auto_security_group:
+            parameters[AUTO_SECURITY_GROUP_PARAM_NAME] = {'type': "string"}
+
         return yaml.safe_dump({
             "heat_template_version": heat_common.HEAT_TEMPLATE_VERSION,
             "description": self._node_group_description(ng),
@@ -257,28 +334,20 @@ class ClusterStack(object):
         })
 
     def _serialize_auto_security_group(self, ng):
+        if not ng.auto_security_group:
+            return {}
         security_group_name = g.generate_auto_security_group_name(ng)
         security_group_description = self._asg_for_node_group_description(ng)
 
-        if CONF.use_neutron:
-            res_type = "OS::Neutron::SecurityGroup"
-            desc_key = "description"
-            rules_key = "rules"
-            create_rule = lambda ip_version, cidr, proto, from_port, to_port: {
-                "ethertype": "IPv{}".format(ip_version),
-                "remote_ip_prefix": cidr,
-                "protocol": proto,
-                "port_range_min": six.text_type(from_port),
-                "port_range_max": six.text_type(to_port)}
-        else:
-            res_type = "AWS::EC2::SecurityGroup"
-            desc_key = "GroupDescription"
-            rules_key = "SecurityGroupIngress"
-            create_rule = lambda _, cidr, proto, from_port, to_port: {
-                "CidrIp": cidr,
-                "IpProtocol": proto,
-                "FromPort": six.text_type(from_port),
-                "ToPort": six.text_type(to_port)}
+        res_type = "OS::Neutron::SecurityGroup"
+        desc_key = "description"
+        rules_key = "rules"
+        create_rule = lambda ip_version, cidr, proto, from_port, to_port: {
+            "ethertype": "IPv{}".format(ip_version),
+            "remote_ip_prefix": cidr,
+            "protocol": proto,
+            "port_range_min": six.text_type(from_port),
+            "port_range_max": six.text_type(to_port)}
 
         rules = self._serialize_auto_security_group_rules(ng, create_rule)
 
@@ -302,12 +371,11 @@ class ClusterStack(object):
         rules.append(create_rule(6, '::/0', 'tcp', SSH_PORT, SSH_PORT))
 
         # open all traffic for private networks
-        if CONF.use_neutron:
-            for cidr in neutron.get_private_network_cidrs(ng.cluster):
-                ip_ver = 6 if ':' in cidr else 4
-                for protocol in ['tcp', 'udp']:
-                    rules.append(create_rule(ip_ver, cidr, protocol, 1, 65535))
-                rules.append(create_rule(ip_ver, cidr, 'icmp', 0, 255))
+        for cidr in neutron.get_private_network_cidrs(ng.cluster):
+            ip_ver = 6 if ':' in cidr else 4
+            for protocol in ['tcp', 'udp']:
+                rules.append(create_rule(ip_ver, cidr, protocol, 1, 65535))
+            rules.append(create_rule(ip_ver, cidr, 'icmp', 0, 255))
 
         return rules
 
@@ -320,36 +388,110 @@ class ClusterStack(object):
         return int(configs.get(cfg_target,
                                {}).get(cfg_name, timeout_cfg.default_value))
 
+    def _serialize_designate_records(self):
+        if not self.cluster.use_designate_feature():
+            return {}
+        hostname = _get_inst_domain_name(self.cluster.domain_name)
+        return {
+            INTERNAL_DESIGNATE_REC: {
+                'type': 'OS::Designate::Record',
+                'properties': {
+                    'name': hostname,
+                    'type': 'A',
+                    'data': {'get_attr': [
+                        INSTANCE_RESOURCE_NAME, 'networks', 'private', 0]},
+                    'domain': self.cluster.domain_name
+                }
+            },
+            EXTERNAL_DESIGNATE_REC: {
+                'type': 'OS::Designate::Record',
+                'properties': {
+                    'name': hostname,
+                    'type': 'A',
+                    'data': {'get_attr': ['floating_ip', 'ip']},
+                    'domain': self.cluster.domain_name
+                }
+            }
+        }
+
+    def _serialize_designate_reverse_records(self):
+
+        if not self.cluster.use_designate_feature():
+            return {}
+
+        def _generate_reversed_ip(ip):
+            return {
+                'list_join': [
+                    '.',
+                    [
+                        {'str_split': ['.', ip, 3]},
+                        {'str_split': ['.', ip, 2]},
+                        {'str_split': ['.', ip, 1]},
+                        {'str_split': ['.', ip, 0]},
+                        'in-addr.arpa.'
+                    ]
+                ]
+            }
+
+        hostname = _get_inst_domain_name(self.cluster.domain_name)
+        return {
+            INTERNAL_DESIGNATE_REV_REC: {
+                'type': 'OS::Designate::Record',
+                'properties': {
+                    'name': _generate_reversed_ip({'get_attr': [
+                        INSTANCE_RESOURCE_NAME, 'networks', 'private', 0]}),
+                    'type': 'PTR',
+                    'data': hostname,
+                    'domain': 'in-addr.arpa.'
+                }
+            },
+            EXTERNAL_DESIGNATE_REV_REC: {
+                'type': 'OS::Designate::Record',
+                'properties': {
+                    'name':  _generate_reversed_ip(
+                        {'get_attr': ['floating_ip', 'ip']}),
+                    'type': 'PTR',
+                    'data': hostname,
+                    'domain': 'in-addr.arpa.'
+                }
+            }
+        }
+
     def _serialize_instance(self, ng):
         resources = {}
         properties = {}
 
         inst_name = _get_inst_name(ng)
+        private_net = self.cluster.neutron_management_network
 
-        if ng.auto_security_group:
-            resources.update(self._serialize_auto_security_group(ng))
-
-        if ng.floating_ip_pool:
-            resources.update(self._serialize_nova_floating(ng))
-
-        if CONF.use_neutron:
-            properties["networks"] = [{
-                "network": self.cluster.neutron_management_network}]
-
-        if ng.security_groups or ng.auto_security_group:
-            properties["security_groups"] = self._get_security_groups(ng)
+        sec_groups = self._get_security_groups(ng)
 
         # Check if cluster contains user key-pair and include it to template.
         if self.cluster.user_keypair_id:
             properties["key_name"] = self.cluster.user_keypair_id
 
+        port_name = _get_port_name(ng)
+
+        resources.update(self._serialize_port(
+            port_name, private_net, sec_groups))
+
+        properties["networks"] = [{"port": {"get_resource": "port"}}]
+
+        if ng.floating_ip_pool:
+            resources.update(self._serialize_neutron_floating(ng))
+
         gen_userdata_func = self.node_groups_extra[ng.id]['gen_userdata_func']
         key_script = gen_userdata_func(ng, inst_name)
         if CONF.heat_enable_wait_condition:
+            etc_hosts = cl.etc_hosts_entry_for_service('orchestration')
+            if etc_hosts:
+                etc_hosts = "echo '%s' | sudo tee -a /etc/hosts" % etc_hosts
+            tml = [key_script, WAIT_CONDITION_SCRIPT_TEMPLATE]
+            if etc_hosts:
+                tml = [key_script, etc_hosts, WAIT_CONDITION_SCRIPT_TEMPLATE]
             userdata = {
                 "str_replace": {
-                    "template": "\n".join([
-                        key_script, WAIT_CONDITION_SCRIPT_TEMPLATE]),
+                    "template": "\n".join(tml),
                     "params": {
                         "wc_notify": {
                             "get_attr": [
@@ -371,11 +513,20 @@ class ClusterStack(object):
         properties.update({
             "name": inst_name,
             "flavor": six.text_type(ng.flavor_id),
-            "image": ng.get_image_id(),
             "admin_user": ng.image_username,
             "user_data": userdata
         })
 
+        if ng.boot_from_volume:
+            resources.update(self._get_bootable_volume(ng))
+            properties["block_device_mapping"] = [
+                {"device_name": "vda",
+                 "volume_id": {"get_resource": "bootable_volume"},
+                 "delete_on_termination": "true"}]
+
+        else:
+            properties.update({"image": ng.get_image_id()})
+
         resources.update({
             INSTANCE_RESOURCE_NAME: {
                 "type": "OS::Nova::Server",
@@ -383,10 +534,26 @@ class ClusterStack(object):
             }
         })
 
+        resources.update(self._serialize_designate_records())
+        resources.update(self._serialize_designate_reverse_records())
         resources.update(self._serialize_volume(ng))
         resources.update(self._serialize_wait_condition(ng))
         return resources
 
+    def _get_bootable_volume(self, node_group):
+        node_group_flavor = nova.get_flavor(id=node_group.flavor_id)
+        image_size = node_group_flavor.disk
+
+        return {
+            "bootable_volume": {
+                "type": "OS::Cinder::Volume",
+                "properties": {
+                    "size": image_size,
+                    "image": node_group.get_image_id()
+                }
+            }
+        }
+
     def _serialize_wait_condition(self, ng):
         if not CONF.heat_enable_wait_condition:
             return {}
@@ -404,23 +571,33 @@ class ClusterStack(object):
             }
         }
 
-    def _serialize_nova_floating(self, ng):
+    def _serialize_neutron_floating(self, ng):
         return {
             "floating_ip": {
-                "type": "OS::Nova::FloatingIP",
+                "type": "OS::Neutron::FloatingIP",
                 "properties": {
-                    "pool": ng.floating_ip_pool
-                }
-            },
-            "floating_ip_assoc": {
-                "type": "OS::Nova::FloatingIPAssociation",
-                "properties": {
-                    "floating_ip": {"get_resource": "floating_ip"},
-                    "server_id": {"get_resource": INSTANCE_RESOURCE_NAME}
+                    "floating_network_id": ng.floating_ip_pool,
+                    "port_id": {"get_resource": "port"}
                 }
             }
         }
 
+    def _serialize_port(self, port_name, fixed_net_id, security_groups):
+        properties = {
+            "network_id": fixed_net_id,
+            "replacement_policy": "AUTO",
+            "name": port_name
+        }
+        if security_groups:
+            properties["security_groups"] = security_groups
+
+        return {
+            "port": {
+                "type": "OS::Neutron::Port",
+                "properties": properties,
+            }
+        }
+
     def _serialize_volume(self, ng):
         if not ng.volumes_size or not ng.volumes_per_node:
             return {}
@@ -492,13 +669,13 @@ class ClusterStack(object):
         node_group_sg = list(node_group.security_groups or [])
         if node_group.auto_security_group:
             node_group_sg += [
-                {"get_resource": g.generate_auto_security_group_name(
-                    node_group)}
+                {"get_param": AUTO_SECURITY_GROUP_PARAM_NAME}
             ]
         return node_group_sg
 
-    def _serialize_aa_server_group(self):
-        server_group_name = _get_aa_group_name(self.cluster)
+    def _serialize_aa_server_group(self, server_group_index):
+        server_group_name = _get_aa_group_name(self.cluster,
+                                               server_group_index)
         return {
             server_group_name: {
                 "type": "OS::Nova::ServerGroup",
