@@ -22,8 +22,6 @@ from oslo_log import log as logging
 from sahara import conductor as c
 from sahara import context
 from sahara.i18n import _
-from sahara.i18n import _LE
-from sahara.i18n import _LW
 from sahara.plugins import provisioning as plugin_base
 from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils.openstack import base as b
@@ -70,6 +68,7 @@ def _check_installed_xfs(instance):
         "centos": redhat,
         "fedora": redhat,
         "redhatenterpriseserver": redhat,
+        "redhat": redhat,
         "ubuntu": debian,
         'debian': debian
     }
@@ -77,16 +76,14 @@ def _check_installed_xfs(instance):
     with instance.remote() as r:
         distro = _get_os_distrib(r)
         if not cmd_map.get(distro):
-            LOG.warning(
-                _LW("Cannot verify installation of XFS tools for "
-                    "unknown distro {distro}.").format(distro=distro))
+            LOG.warning("Cannot verify installation of XFS tools for "
+                        "unknown distro {distro}.".format(distro=distro))
             return False
         try:
             r.execute_command(cmd_map.get(distro), run_as_root=True)
             return True
         except Exception as e:
-            LOG.warning(
-                _LW("Cannot install xfsprogs: {reason}").format(reason=e))
+            LOG.warning("Cannot install xfsprogs: {reason}".format(reason=e))
             return False
 
 
@@ -160,7 +157,8 @@ def _find_instance_devices(instance):
         idx = re.sub("\D", "", dev)
         if idx:
             if dev in mounted_dev:
-                attached_dev.remove(re.sub("\d", "", dev))
+                if re.sub("\d", "", dev) in attached_dev:
+                    attached_dev.remove(re.sub("\d", "", dev))
                 attached_dev.remove(dev)
 
     for dev in attached_dev[:]:
@@ -201,9 +199,8 @@ def _format_device(
                 with lock:
                     formatted_devices.append(device)
         except Exception as e:
-            LOG.warning(
-                _LW("Device {dev} cannot be formatted: {reason}").format(
-                    dev=device, reason=e))
+            LOG.warning("Device {dev} cannot be formatted: {reason}".format(
+                        dev=device, reason=e))
             cpo.add_fail_event(instance, e)
 
 
@@ -229,7 +226,7 @@ def _mount_volume(instance, device_path, mount_point, use_xfs):
                 'sudo sh -c "grep %s /etc/mtab >> /etc/fstab"' % device_path)
 
         except Exception:
-            LOG.error(_LE("Error mounting volume to instance"))
+            LOG.error("Error mounting volume to instance")
             raise
 
 
@@ -255,7 +252,7 @@ def _detach_volume(instance, volume_id):
         b.execute_with_retries(nova.client().volumes.delete_server_volume,
                                instance.instance_id, volume_id)
     except Exception:
-        LOG.error(_LE("Can't detach volume {id}").format(id=volume.id))
+        LOG.error("Can't detach volume {id}".format(id=volume.id))
 
     detach_timeout = CONF.timeouts.detach_volume_timeout
     LOG.debug("Waiting {timeout} seconds to detach {id} volume".format(
@@ -269,5 +266,4 @@ def _delete_volume(volume_id):
     try:
         b.execute_with_retries(volume.delete)
     except Exception:
-        LOG.error(_LE("Can't delete volume {volume}").format(
-            volume=volume.id))
+        LOG.error("Can't delete volume {volume}".format(volume=volume.id))
