@@ -607,6 +607,33 @@ class SaharaMigrationsCheckers(object):
         self.assertColumnsExist(engine, 'cluster_health_checks',
                                 health_check_columns)
 
+    def _check_031(self, engine, data):
+        plugins_data_columns = [
+            'name',
+            'id',
+            'tenant_id',
+            'version_labels',
+            'plugin_labels',
+            'updated_at',
+            'created_at'
+        ]
+
+        self.assertColumnCount(engine, 'plugin_data',
+                               plugins_data_columns)
+        self.assertColumnsExist(engine, 'plugin_data',
+                                plugins_data_columns)
+
+    def _check_033(self, engine, data):
+        self.assertColumnExists(engine, 'clusters', 'anti_affinity_ratio')
+
+    def _check_034(self, engine, data):
+        self.assertColumnExists(engine, 'node_groups',
+                                'boot_from_volume')
+        self.assertColumnExists(engine, 'node_group_templates',
+                                'boot_from_volume')
+        self.assertColumnExists(engine, 'templates_relations',
+                                'boot_from_volume')
+
 
 class TestMigrationsMySQL(SaharaMigrationsCheckers,
                           base.BaseWalkMigrationTestCase,
