@@ -16,16 +16,16 @@
 import mock
 import six
 
-from sahara.plugins.cdh.v5_7_0 import edp_engine
-from sahara.plugins.cdh.v5_7_0 import versionhandler
+from sahara.plugins.cdh.v5_11_0 import edp_engine
+from sahara.plugins.cdh.v5_11_0 import versionhandler
 from sahara.tests.unit import base
 
 
 class VersionHandlerTestCase(base.SaharaTestCase):
 
-    plugin_path = "sahara.plugins.cdh.v5_7_0."
-    cloudera_utils_path = plugin_path + "cloudera_utils.ClouderaUtilsV570."
-    plugin_utils_path = plugin_path + "plugin_utils.PluginUtilsV570."
+    plugin_path = "sahara.plugins.cdh.v5_11_0."
+    cloudera_utils_path = plugin_path + "cloudera_utils.ClouderaUtilsV5110."
+    plugin_utils_path = plugin_path + "plugin_utils.PluginUtilsV5110."
 
     def setUp(self):
         super(VersionHandlerTestCase, self).setUp()
@@ -60,7 +60,7 @@ class VersionHandlerTestCase(base.SaharaTestCase):
         self.vh._set_cluster_info.assert_called_once_with(cluster)
 
     @mock.patch(plugin_path + "deploy.decommission_cluster")
-    def test_decommmission_nodes(self, decommission_cluster):
+    def test_decommission_nodes(self, decommission_cluster):
         cluster = mock.Mock()
         instances = mock.Mock()
         self.vh.decommission_nodes(cluster, instances)
