@@ -14,6 +14,7 @@
 # limitations under the License.
 
 import mock
+from oslo_utils import uuidutils
 import yaml
 
 from sahara import exceptions as ex
@@ -47,14 +48,14 @@ class TestImages(b.SaharaTestCase):
 
         validator = cls.from_spec('test_images.py', {}, resource_roots)
         self.assertIsInstance(validator, cls)
-        self.assertEqual(validator.env_vars, ['reconcile', 'distro'])
+        self.assertEqual(validator.env_vars, ['test_only', 'distro'])
 
         validator = cls.from_spec(
             {'test_images.py': {'env_vars': ['extra-file', 'user']}},
             {}, resource_roots)
         self.assertIsInstance(validator, cls)
         self.assertEqual(validator.env_vars,
-                         ['reconcile', 'distro',
+                         ['test_only', 'distro',
                           'extra-file', 'user'])
 
     def test_all_spec(self):
@@ -181,7 +182,7 @@ class TestImages(b.SaharaTestCase):
         packages = [cls.Package("java", "8")]
         validator = images.SaharaPackageValidator(packages)
         remote = mock.Mock()
-        validator.validate(remote, reconcile=False,
+        validator.validate(remote, test_only=True,
                            image_arguments=image_arguments)
         remote.execute_command.assert_called_with(
             "rpm -q java-8", run_as_root=True)
@@ -193,7 +194,7 @@ class TestImages(b.SaharaTestCase):
         remote.execute_command.side_effect = (
             ex.RemoteCommandException("So bad!"))
         try:
-            validator.validate(remote, reconcile=False,
+            validator.validate(remote, test_only=True,
                                image_arguments=image_arguments)
         except p_ex.ImageValidationError as e:
             self.assertIn("So bad!", e.message)
@@ -201,7 +202,7 @@ class TestImages(b.SaharaTestCase):
             "rpm -q java-8 hadoop", run_as_root=True)
         self.assertEqual(remote.execute_command.call_count, 1)
 
-        image_arguments = {"distro": 'redhatenterpriseserver'}
+        image_arguments = {"distro": 'redhat'}
         packages = [cls.Package("java", "8"), cls.Package("hadoop")]
         validator = images.SaharaPackageValidator(packages)
         remote = mock.Mock()
@@ -212,7 +213,7 @@ class TestImages(b.SaharaTestCase):
 
         remote.execute_command.side_effect = side_effect
         try:
-            validator.validate(remote, reconcile=True,
+            validator.validate(remote, test_only=False,
                                image_arguments=image_arguments)
         except p_ex.ImageValidationError as e:
             self.assertIn("So bad!", e.message)
@@ -229,7 +230,7 @@ class TestImages(b.SaharaTestCase):
         packages = [cls.Package("java", "8")]
         validator = images.SaharaPackageValidator(packages)
         remote = mock.Mock()
-        validator.validate(remote, reconcile=False,
+        validator.validate(remote, test_only=True,
                            image_arguments=image_arguments)
         remote.execute_command.assert_called_with(
             "dpkg -s java-8", run_as_root=True)
@@ -241,7 +242,7 @@ class TestImages(b.SaharaTestCase):
         remote.execute_command.side_effect = (
             ex.RemoteCommandException("So bad!"))
         try:
-            validator.validate(remote, reconcile=False,
+            validator.validate(remote, test_only=True,
                                image_arguments=image_arguments)
         except p_ex.ImageValidationError as e:
             self.assertIn("So bad!", e.message)
@@ -256,7 +257,7 @@ class TestImages(b.SaharaTestCase):
         remote.execute_command.side_effect = (
             ex.RemoteCommandException("So bad!"))
         try:
-            validator.validate(remote, reconcile=True,
+            validator.validate(remote, test_only=False,
                                image_arguments=image_arguments)
         except p_ex.ImageValidationError as e:
             self.assertIn("So bad!", e.message)
@@ -267,12 +268,13 @@ class TestImages(b.SaharaTestCase):
                            run_as_root=True)]
         remote.execute_command.assert_has_calls(calls)
 
-    def test_script_validator(self):
+    @mock.patch('oslo_utils.uuidutils.generate_uuid')
+    def test_script_validator(self, uuid):
+        hash_value = '00000000-0000-0000-0000-000000000000'
+        uuidutils.generate_uuid.return_value = hash_value
         cls = images.SaharaScriptValidator
         image_arguments = {"distro": 'centos'}
-        map_rep = "export distro=centos\n"
         cmd = "It's dangerous to go alone. Run this."
-        expected_cmd = "bash <<_SIV_\n%s\n_SIV_" % cmd
         validator = cls(cmd, env_vars=image_arguments.keys(),
                         output_var="distro")
 
@@ -280,9 +282,12 @@ class TestImages(b.SaharaTestCase):
             execute_command=mock.Mock(
                 return_value=(0, 'fedora')))
 
-        validator.validate(remote, reconcile=True,
+        validator.validate(remote, test_only=False,
                            image_arguments=image_arguments)
-        call = [mock.call(map_rep + expected_cmd, run_as_root=True)]
+        call = [mock.call('chmod +x /tmp/%(hash_value)s.sh' %
+                          {'hash_value': hash_value}, run_as_root=True),
+                mock.call('/tmp/%(hash_value)s.sh' %
+                          {'hash_value': hash_value}, run_as_root=True)]
         remote.execute_command.assert_has_calls(call)
         self.assertEqual(image_arguments['distro'], 'fedora')
 
@@ -294,31 +299,31 @@ class TestImages(b.SaharaTestCase):
             def __init__(self, mock_validate):
                 self.mock_validate = mock_validate
 
-            def validate(self, remote, reconcile=True, **kwargs):
-                self.mock_validate(remote, reconcile=reconcile, **kwargs)
+            def validate(self, remote, test_only=False, **kwargs):
+                self.mock_validate(remote, test_only=test_only, **kwargs)
 
         # One success short circuits validation
         always_tells_the_truth = FakeValidator(mock.Mock())
         validator = cls([always_tells_the_truth, always_tells_the_truth])
-        validator.validate(None, reconcile=True)
+        validator.validate(None, test_only=False)
         self.assertEqual(always_tells_the_truth.mock_validate.call_count, 1)
 
-        # All failures fails, and calls with reconcile=False on all first
+        # All failures fails, and calls with test_only=True on all first
         always_lies = FakeValidator(
             mock.Mock(side_effect=p_ex.ImageValidationError("Oh no!")))
         validator = cls([always_lies, always_lies])
         try:
-            validator.validate(None, reconcile=True)
+            validator.validate(None, test_only=False)
         except p_ex.ImageValidationError:
             pass
         self.assertEqual(always_lies.mock_validate.call_count, 4)
 
-        # But it fails after a first pass if reconcile=False.
+        # But it fails after a first pass if test_only=True.
         always_lies = FakeValidator(
             mock.Mock(side_effect=p_ex.ImageValidationError("Oh no!")))
         validator = cls([always_lies, always_lies])
         try:
-            validator.validate(None, reconcile=False)
+            validator.validate(None, test_only=True)
         except p_ex.ImageValidationError:
             pass
         self.assertEqual(always_lies.mock_validate.call_count, 2)
@@ -328,7 +333,7 @@ class TestImages(b.SaharaTestCase):
         always_lies = FakeValidator(
             mock.Mock(side_effect=p_ex.ImageValidationError("Oh no!")))
         validator = cls([always_lies, always_tells_the_truth])
-        validator.validate(None, reconcile=True)
+        validator.validate(None, test_only=False)
         self.assertEqual(always_lies.mock_validate.call_count, 1)
         self.assertEqual(always_tells_the_truth.mock_validate.call_count, 1)
 
@@ -338,10 +343,10 @@ class TestImages(b.SaharaTestCase):
         # All pass
         always_tells_the_truth = mock.Mock()
         validator = cls([always_tells_the_truth, always_tells_the_truth])
-        validator.validate(None, reconcile=True)
+        validator.validate(None, test_only=False)
         self.assertEqual(always_tells_the_truth.validate.call_count, 2)
         always_tells_the_truth.validate.assert_called_with(
-            None, reconcile=True, image_arguments=None)
+            None, test_only=False, image_arguments=None)
 
         # Second fails
         always_tells_the_truth = mock.Mock()
@@ -349,15 +354,15 @@ class TestImages(b.SaharaTestCase):
             side_effect=p_ex.ImageValidationError("Boom!")))
         validator = cls([always_tells_the_truth, always_lies])
         try:
-            validator.validate(None, reconcile=False)
+            validator.validate(None, test_only=True)
         except p_ex.ImageValidationError:
             pass
         self.assertEqual(always_tells_the_truth.validate.call_count, 1)
         self.assertEqual(always_lies.validate.call_count, 1)
         always_tells_the_truth.validate.assert_called_with(
-            None, reconcile=False, image_arguments=None)
+            None, test_only=True, image_arguments=None)
         always_lies.validate.assert_called_with(
-            None, reconcile=False, image_arguments=None)
+            None, test_only=True, image_arguments=None)
 
         # First fails
         always_tells_the_truth = mock.Mock()
@@ -365,12 +370,12 @@ class TestImages(b.SaharaTestCase):
             side_effect=p_ex.ImageValidationError("Boom!")))
         validator = cls([always_lies, always_tells_the_truth])
         try:
-            validator.validate(None, reconcile=False, image_arguments={})
+            validator.validate(None, test_only=True, image_arguments={})
         except p_ex.ImageValidationError:
             pass
         self.assertEqual(always_lies.validate.call_count, 1)
         always_lies.validate.assert_called_with(
-            None, reconcile=False, image_arguments={})
+            None, test_only=True, image_arguments={})
         self.assertEqual(always_tells_the_truth.validate.call_count, 0)
 
     def test_os_case_validator(self):
@@ -383,25 +388,25 @@ class TestImages(b.SaharaTestCase):
         distros = [centos, redhat]
         image_arguments = {images.SaharaImageValidator.DISTRO_KEY: "centos"}
         validator = cls(distros)
-        validator.validate(None, reconcile=True,
+        validator.validate(None, test_only=False,
                            image_arguments=image_arguments)
         self.assertEqual(centos.validator.validate.call_count, 1)
         self.assertEqual(redhat.validator.validate.call_count, 0)
         centos.validator.validate.assert_called_with(
-            None, reconcile=True, image_arguments=image_arguments)
+            None, test_only=False, image_arguments=image_arguments)
 
-        # Familes match
+        # Families match
         centos = Distro("centos", mock.Mock())
         redhat = Distro("redhat", mock.Mock())
         distros = [centos, redhat]
         image_arguments = {images.SaharaImageValidator.DISTRO_KEY: "fedora"}
         validator = cls(distros)
-        validator.validate(None, reconcile=True,
+        validator.validate(None, test_only=False,
                            image_arguments=image_arguments)
         self.assertEqual(centos.validator.validate.call_count, 0)
         self.assertEqual(redhat.validator.validate.call_count, 1)
         redhat.validator.validate.assert_called_with(
-            None, reconcile=True, image_arguments=image_arguments)
+            None, test_only=False, image_arguments=image_arguments)
 
         # Non-matches do nothing
         centos = Distro("centos", mock.Mock())
@@ -409,7 +414,7 @@ class TestImages(b.SaharaTestCase):
         distros = [centos, redhat]
         image_arguments = {images.SaharaImageValidator.DISTRO_KEY: "ubuntu"}
         validator = cls(distros)
-        validator.validate(None, reconcile=True,
+        validator.validate(None, test_only=False,
                            image_arguments=image_arguments)
         self.assertEqual(centos.validator.validate.call_count, 0)
         self.assertEqual(redhat.validator.validate.call_count, 0)
@@ -424,12 +429,12 @@ class TestImages(b.SaharaTestCase):
         cases = {"value": match,
                  "another_value": nomatch}
         validator = cls("argument", cases)
-        validator.validate(None, reconcile=True,
+        validator.validate(None, test_only=False,
                            image_arguments=image_arguments)
         self.assertEqual(match.validate.call_count, 1)
         self.assertEqual(nomatch.validate.call_count, 0)
         match.validate.assert_called_with(
-            None, reconcile=True, image_arguments=image_arguments)
+            None, test_only=False, image_arguments=image_arguments)
 
         # Non-matches do nothing
         image_arguments = {"argument": "value"}
@@ -437,7 +442,7 @@ class TestImages(b.SaharaTestCase):
         cases = {"some_value": nomatch,
                  "another_value": nomatch}
         validator = cls("argument", cases)
-        validator.validate(None, reconcile=True,
+        validator.validate(None, test_only=False,
                            image_arguments=image_arguments)
         self.assertEqual(nomatch.validate.call_count, 0)
 
@@ -447,14 +452,14 @@ class TestImages(b.SaharaTestCase):
         # Old variable is overwritten
         image_arguments = {"argument": "value"}
         validator = cls("argument", "new_value")
-        validator.validate(None, reconcile=True,
+        validator.validate(None, test_only=False,
                            image_arguments=image_arguments)
         self.assertEqual(image_arguments["argument"], "new_value")
 
         # New variable is set
         image_arguments = {"argument": "value"}
         validator = cls("another_argument", "value")
-        validator.validate(None, reconcile=True,
+        validator.validate(None, test_only=False,
                            image_arguments=image_arguments)
         self.assertEqual(image_arguments,
                          {"argument": "value", "another_argument": "value"})
@@ -466,11 +471,11 @@ class TestImages(b.SaharaTestCase):
         remote = mock.Mock(get_os_distrib=mock.Mock(
             return_value="centos"))
         validator = cls(sub_validator, {})
-        validator.validate(remote, reconcile=True, image_arguments={})
+        validator.validate(remote, test_only=False, image_arguments={})
         expected_map = {images.SaharaImageValidatorBase.DISTRO_KEY: "centos"}
         sub_validator.validate.assert_called_with(
-            remote, reconcile=True, image_arguments=expected_map)
+            remote, test_only=False, image_arguments=expected_map)
         expected_map = {images.SaharaImageValidatorBase.DISTRO_KEY: "centos"}
-        validator.validate(remote, reconcile=False, image_arguments={})
+        validator.validate(remote, test_only=True, image_arguments={})
         sub_validator.validate.assert_called_with(
-            remote, reconcile=False, image_arguments=expected_map)
+            remote, test_only=True, image_arguments=expected_map)
