@@ -13,17 +13,64 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from keystoneclient.auth import identity as keystone_identity
-from keystoneclient import session as keystone_session
+import re
+
+from keystoneauth1 import identity as keystone_identity
 from keystoneclient.v2_0 import client as keystone_client
 from keystoneclient.v3 import client as keystone_client_v3
 from oslo_config import cfg
+from oslo_log import log as logging
 
 from sahara import context
 from sahara.service import sessions
 from sahara.utils.openstack import base
 
 
+LOG = logging.getLogger(__name__)
+
+
+def _get_keystoneauth_cfg(name):
+    """get the keystone auth cfg
+
+    Fetch value of keystone_authtoken group from config file when not
+    available as part of GroupAttr.
+    :rtype: String
+    :param name: property name to be retrieved
+    """
+    try:
+        value_list = CONF._namespace._get_file_value([('keystone_authtoken',
+                                                       name)])
+        if isinstance(value_list, tuple):
+            value_list = value_list[0]
+        cfg_val = value_list[0]
+        if name == "auth_url" and not re.findall(r'\/v[2-3].*', cfg_val):
+            cfg_val += "/v3"
+        return cfg_val
+    except KeyError:
+        if name in ["user_domain_name", "project_domain_name"]:
+            return "Default"
+        else:
+            raise
+
+
+def validate_config():
+    if any(map(lambda o: getattr(CONF.trustee, o) is None, CONF.trustee)):
+        for replace_opt in CONF.trustee:
+            CONF.set_override(replace_opt, _get_keystoneauth_cfg(replace_opt),
+                              group="trustee")
+        LOG.warning("""
+ __        __               _
+ \ \      / /_ _ _ __ _ __ (_)_ __   __ _
+  \ \ /\ / / _` | '__| '_ \| | '_ \ / _` |
+   \ V  V / (_| | |  | | | | | | | | (_| |
+    \_/\_/ \__,_|_|  |_| |_|_|_| |_|\__, |
+                                    |___/
+
+Using the [keystone_authtoken] user as the Sahara trustee user directly is
+deprecated. Please add the trustee credentials you need to the [trustee]
+section of your sahara.conf file.
+    """)
+
 opts = [
     # TODO(alazarev) Move to [keystone] section
     cfg.BoolOpt('use_identity_api_v3',
@@ -31,17 +78,7 @@ opts = [
                 help='Enables Sahara to use Keystone API v3. '
                      'If that flag is disabled, '
                      'per-job clusters will not be terminated '
-                     'automatically.'),
-    # TODO(mimccune) The following should be integrated into a custom
-    # auth section
-    cfg.StrOpt('admin_user_domain_name',
-               default='default',
-               help='The name of the domain to which the admin user '
-                    'belongs.'),
-    cfg.StrOpt('admin_project_domain_name',
-               default='default',
-               help='The name of the domain for the service '
-                    'project(ex. tenant).')
+                     'automatically.')
 ]
 
 ssl_opts = [
@@ -59,10 +96,31 @@ ssl_opts = [
 keystone_group = cfg.OptGroup(name='keystone',
                               title='Keystone client options')
 
+trustee_opts = [
+    cfg.StrOpt('username',
+               help='Username for trusts creation'),
+    cfg.StrOpt('password',
+               help='Password for trusts creation'),
+    cfg.StrOpt('project_name',
+               help='Project name for trusts creation'),
+    cfg.StrOpt('user_domain_name',
+               help='User domain name for trusts creation',
+               default="Default"),
+    cfg.StrOpt('project_domain_name',
+               help='Project domain name for trusts creation',
+               default="Default"),
+    cfg.StrOpt('auth_url',
+               help='Auth url for trusts creation'),
+]
+
+trustee_group = cfg.OptGroup(name='trustee', title="Trustee options")
+
 CONF = cfg.CONF
 CONF.register_group(keystone_group)
+CONF.register_group(trustee_group)
 CONF.register_opts(opts)
 CONF.register_opts(ssl_opts, group=keystone_group)
+CONF.register_opts(trustee_opts, group=trustee_group)
 
 
 def auth():
@@ -85,11 +143,11 @@ def auth_for_admin(project_name=None, trust_id=None):
     # into federated authentication. it will need to match the domain that
     # the project_name exists in.
     auth = _password_auth(
-        username=CONF.keystone_authtoken.admin_user,
-        password=CONF.keystone_authtoken.admin_password,
+        username=CONF.trustee.username,
+        password=CONF.trustee.password,
         project_name=project_name,
-        user_domain_name=CONF.admin_user_domain_name,
-        project_domain_name=CONF.admin_project_domain_name,
+        user_domain_name=CONF.trustee.user_domain_name,
+        project_domain_name=CONF.trustee.project_domain_name,
         trust_id=trust_id)
     return auth
 
@@ -121,7 +179,7 @@ def client():
 def client_for_admin():
     '''Return the Sahara admin user client.'''
     auth = auth_for_admin(
-        project_name=CONF.keystone_authtoken.admin_tenant_name)
+        project_name=CONF.trustee.project_name)
     return client_from_auth(auth)
 
 
@@ -160,24 +218,12 @@ def service_catalog_from_auth(auth):
 
     :returns: a list containing the service catalog.
     '''
-    if CONF.use_identity_api_v3:
-        return auth.get_access(
-            sessions.cache().get_session()).get('catalog', [])
+    access_info = auth.get_access(
+        sessions.cache().get_session(sessions.SESSION_TYPE_KEYSTONE))
+    if access_info.has_service_catalog():
+        return access_info.service_catalog.catalog
     else:
-        return auth.get_access(
-            sessions.cache().get_session()).get('serviceCatalog', [])
-
-
-# TODO(elmiko) factor this out when redoing the barbicanclient
-def session_for_admin():
-    '''Return a Keystone session for the admin user.'''
-    auth = _password_auth(
-        username=CONF.keystone_authtoken.admin_user,
-        password=CONF.keystone_authtoken.admin_password,
-        project_name=CONF.keystone_authtoken.admin_tenant_name,
-        user_domain_name=CONF.admin_user_domain_name,
-        project_domain_name=CONF.admin_project_domain_name)
-    return keystone_session.Session(auth=auth)
+        return []
 
 
 def token_auth(token, project_id=None, project_name=None,
@@ -217,8 +263,7 @@ def token_from_auth(auth):
 
     :returns: an auth token in string format.
     '''
-    return keystone_session.Session(
-        auth=auth, verify=CONF.generic_session_verify).get_token()
+    return sessions.cache().token_for_auth(auth)
 
 
 def user_id_from_auth(auth):
@@ -232,38 +277,6 @@ def user_id_from_auth(auth):
         sessions.SESSION_TYPE_KEYSTONE))
 
 
-# TODO(elmiko) deprecate this when all client have been migrated to sessions
-def _client(username, password=None, token=None, tenant_name=None,
-            tenant_id=None, trust_id=None, domain_name=None):
-
-    if trust_id and not CONF.use_identity_api_v3:
-        raise Exception("Trusts aren't implemented in keystone api"
-                        " less than v3")
-
-    auth_url = base.retrieve_auth_url(
-        endpoint_type=CONF.keystone.endpoint_type)
-
-    client_kwargs = {'username': username,
-                     'password': password,
-                     'token': token,
-                     'tenant_name': tenant_name,
-                     'tenant_id': tenant_id,
-                     'trust_id': trust_id,
-                     'user_domain_name': domain_name,
-                     'auth_url': auth_url,
-                     'cacert': CONF.keystone.ca_file,
-                     'insecure': CONF.keystone.api_insecure
-                     }
-
-    if CONF.use_identity_api_v3:
-        keystone = keystone_client_v3.Client(**client_kwargs)
-        keystone.management_url = auth_url
-    else:
-        keystone = keystone_client.Client(**client_kwargs)
-
-    return keystone
-
-
 def _password_auth(username, password,
                    project_name=None, user_domain_name=None,
                    project_domain_name=None, trust_id=None):
@@ -284,7 +297,7 @@ def _password_auth(username, password,
     :returns: a password auth plugin object.
     '''
     passwd_kwargs = dict(
-        auth_url=base.retrieve_auth_url(CONF.keystone.endpoint_type),
+        auth_url=CONF.trustee.auth_url,
         username=username,
         password=password
     )
