@@ -17,11 +17,10 @@
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
+from oslo_messaging.rpc import dispatcher
 from oslo_serialization import jsonutils
 
 from sahara import context
-from sahara.i18n import _LE
-from sahara.i18n import _LI
 
 
 MESSAGING_TRANSPORT = None
@@ -31,12 +30,6 @@ NOTIFIER = None
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
-_ALIASES = {
-    'sahara.openstack.common.rpc.impl_kombu': 'rabbit',
-    'sahara.openstack.common.rpc.impl_qpid': 'qpid',
-    'sahara.openstack.common.rpc.impl_zmq': 'zmq',
-}
-
 
 class ContextSerializer(messaging.Serializer):
     def __init__(self, base):
@@ -85,11 +78,13 @@ class RPCServer(object):
     def __init__(self, target):
         global MESSAGING_TRANSPORT
 
+        access_policy = dispatcher.DefaultRPCAccessPolicy
         self.__server = messaging.get_rpc_server(
             target=target,
             transport=MESSAGING_TRANSPORT,
             endpoints=[self],
-            executor='eventlet')
+            executor='eventlet',
+            access_policy=access_policy)
 
     def get_service(self):
         return self.__server
@@ -100,42 +95,29 @@ def setup_service_messaging():
     if MESSAGING_TRANSPORT:
         # Already is up
         return
-    MESSAGING_TRANSPORT = messaging.get_transport(cfg.CONF, aliases=_ALIASES)
+    MESSAGING_TRANSPORT = messaging.get_rpc_transport(cfg.CONF)
 
 
 def setup_notifications():
     global NOTIFICATION_TRANSPORT, NOTIFIER, MESSAGING_TRANSPORT
-    if not cfg.CONF.oslo_messaging_notifications.enable:
-        LOG.info(_LI("Notifications disabled"))
-        return
-
     try:
-        NOTIFICATION_TRANSPORT = messaging.get_notification_transport(
-            cfg.CONF, aliases=_ALIASES)
+        NOTIFICATION_TRANSPORT = \
+            messaging.get_notification_transport(cfg.CONF)
     except Exception:
-        LOG.error(_LE("Unable to setup notification transport. Reusing "
-                      "service transport for that."))
-
+        LOG.error("Unable to setup notification transport. Reusing "
+                  "service transport for that.")
         setup_service_messaging()
-
         NOTIFICATION_TRANSPORT = MESSAGING_TRANSPORT
 
     serializer = ContextSerializer(JsonPayloadSerializer())
-    NOTIFIER = messaging.Notifier(
-        NOTIFICATION_TRANSPORT, serializer=serializer)
-    LOG.info(_LI("Notifications enabled"))
+    NOTIFIER = messaging.Notifier(NOTIFICATION_TRANSPORT,
+                                  serializer=serializer)
 
 
 def setup(service_name):
     """Initialise the oslo_messaging layer."""
-    global MESSAGING_TRANSPORT, NOTIFICATION_TRANSPORT, NOTIFIER
-    if (service_name == 'all-in-one' and
-            not cfg.CONF.oslo_messaging_notifications.enable):
-        LOG.info(_LI("Notifications disabled"))
-        return
 
     messaging.set_transport_defaults('sahara')
-
     setup_notifications()
     if service_name != 'all-in-one':
         setup_service_messaging()
