@@ -37,7 +37,6 @@ import shlex
 import sys
 import threading
 import time
-import uuid
 
 from eventlet.green import subprocess as e_subprocess
 from eventlet import semaphore
@@ -45,6 +44,7 @@ from eventlet import timeout as e_timeout
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
+from oslo_utils import uuidutils
 import paramiko
 import requests
 from requests import adapters
@@ -53,7 +53,6 @@ import six
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.i18n import _LE
 from sahara.service import trusts
 from sahara.utils import crypto
 from sahara.utils import network as net_utils
@@ -74,7 +73,7 @@ ssh_config_options = [
         'ssh_timeout_interactive', default=1800, min=1,
         help="Overrides timeout for interactive ssh operations, in seconds"),
     cfg.IntOpt(
-        'ssh_timeout_files', default=120, min=1,
+        'ssh_timeout_files', default=600, min=1,
         help="Overrides timeout for ssh operations with files, in seconds"),
 ]
 
@@ -95,6 +94,12 @@ SSH_TIMEOUTS_MAPPING = {
 _global_remote_semaphore = None
 
 
+def _get_access_ip(instance):
+    if CONF.proxy_command and CONF.proxy_command_use_internal_ip:
+        return instance.internal_ip
+    return instance.management_ip
+
+
 def _default_timeout(func):
     timeout = SSH_TIMEOUTS_MAPPING.get(func.__name__, 'ssh_timeout_files')
     return getattr(CONF, timeout, CONF.ssh_timeout_common)
@@ -173,7 +178,7 @@ def _execute_command(cmd, run_as_root=False, get_stderr=False,
     else:
         chan.exec_command(cmd)
 
-    # todo(dmitryme): that could hang if stderr buffer overflows
+    # TODO(dmitryme): that could hang if stderr buffer overflows
     stdout = _read_paramimko_stream(chan.recv)
     stderr = _read_paramimko_stream(chan.recv_stderr)
 
@@ -265,9 +270,8 @@ def _get_http_client(host, port, proxy_command=None, gateway_host=None,
 
 
 def _write_fl(sftp, remote_file, data):
-    fl = sftp.file(remote_file, 'w')
-    fl.write(data)
-    fl.close()
+    write_data = paramiko.py3compat.StringIO(data)
+    sftp.putfo(write_data, remote_file)
 
 
 def _append_fl(sftp, remote_file, data):
@@ -278,7 +282,7 @@ def _append_fl(sftp, remote_file, data):
 
 def _write_file(sftp, remote_file, data, run_as_root):
     if run_as_root:
-        temp_file = 'temp-file-%s' % six.text_type(uuid.uuid4())
+        temp_file = 'temp-file-%s' % uuidutils.generate_uuid()
         _write_fl(sftp, temp_file, data)
         _execute_command(
             'mv %s %s' % (temp_file, remote_file), run_as_root=True)
@@ -288,7 +292,7 @@ def _write_file(sftp, remote_file, data, run_as_root):
 
 def _append_file(sftp, remote_file, data, run_as_root):
     if run_as_root:
-        temp_file = 'temp-file-%s' % six.text_type(uuid.uuid4())
+        temp_file = 'temp-file-%s' % uuidutils.generate_uuid()
         _write_fl(sftp, temp_file, data)
         _execute_command(
             'cat %s >> %s' % (temp_file, remote_file), run_as_root=True)
@@ -339,14 +343,13 @@ def _read_file_from(remote_file, run_as_root=False):
 
     fl = remote_file
     if run_as_root:
-        fl = 'temp-file-%s' % (six.text_type(uuid.uuid4()))
+        fl = 'temp-file-%s' % (uuidutils.generate_uuid())
         _execute_command('cp %s %s' % (remote_file, fl), run_as_root=True)
 
     try:
         return _read_file(_ssh.open_sftp(), fl)
     except IOError:
-        LOG.error(_LE("Can't read file {filename}").format(
-            filename=remote_file))
+        LOG.error("Can't read file {filename}".format(filename=remote_file))
         raise
     finally:
         if run_as_root:
@@ -354,7 +357,7 @@ def _read_file_from(remote_file, run_as_root=False):
                 'rm %s' % fl, run_as_root=True, raise_when_error=False)
 
 
-def __get_python_to_execute():
+def _get_python_to_execute():
     try:
         _execute_command('python3 --version')
     except Exception:
@@ -364,7 +367,7 @@ def __get_python_to_execute():
 
 
 def _get_os_distrib():
-    python_version = __get_python_to_execute()
+    python_version = _get_python_to_execute()
     return _execute_command(
         ('printf "import platform\nprint(platform.linux_distribution('
          'full_distribution_name=0)[0])" | {}'.format(python_version)),
@@ -372,7 +375,7 @@ def _get_os_distrib():
 
 
 def _get_os_version():
-    python_version = __get_python_to_execute()
+    python_version = _get_python_to_execute()
     return _execute_command(
         ('printf "import platform\nprint(platform.linux_distribution()[1])"'
          ' | {}'.format(python_version)), run_as_root=False)[1].strip()
@@ -641,7 +644,7 @@ class InstanceInteropHelper(remote.Remote):
         ctx = context.current()
         neutron_info['token'] = context.get_auth_token()
         neutron_info['tenant'] = ctx.tenant_name
-        neutron_info['host'] = instance.management_ip
+        neutron_info['host'] = _get_access_ip(instance)
 
         log_info = copy.deepcopy(neutron_info)
         del log_info['token']
@@ -666,13 +669,13 @@ class InstanceInteropHelper(remote.Remote):
                                            info['tenant'], auth=auth)
             keywords['router_id'] = client.get_router()
 
-        keywords['host'] = instance.management_ip
+        keywords['host'] = _get_access_ip(instance)
         keywords['port'] = port
 
         try:
             command = command.format(**keywords)
         except KeyError as e:
-            LOG.error(_LE('Invalid keyword in proxy_command: {result}').format(
+            LOG.error('Invalid keyword in proxy_command: {result}'.format(
                 result=e))
             # Do not give more details to the end-user
             raise ex.SystemError('Misconfiguration')
@@ -715,8 +718,6 @@ class InstanceInteropHelper(remote.Remote):
         # fp -- just compare to internal?
         # in the neutron case, we check the node group for the
         # access_instance and look for fp
-        # in the nova case, we compare management_ip to internal_ip or even
-        # use the nova interface
         elif CONF.use_namespaces and not net_utils.has_floating_ip(
                 access_instance):
             # Build a session through a netcat socket in the Neutron namespace
@@ -730,7 +731,9 @@ class InstanceInteropHelper(remote.Remote):
                 proxy_command, instance=access_instance, port=22,
                 info=None, rootwrap_command=rootwrap)
 
-        return (self.instance.management_ip,
+        host_ip = _get_access_ip(self.instance)
+
+        return (host_ip,
                 host_ng.image_username,
                 cluster.management_private_key,
                 proxy_command,
@@ -773,7 +776,7 @@ class InstanceInteropHelper(remote.Remote):
 
     def get_http_client(self, port, info=None):
         self._log_command('Retrieving HTTP session for {0}:{1}'.format(
-            self.instance.management_ip, port))
+            _get_access_ip(self.instance), port))
 
         host_ng = self.instance.node_group
         cluster = host_ng.cluster
@@ -797,13 +800,10 @@ class InstanceInteropHelper(remote.Remote):
             proxy_command = CONF.proxy_command
 
         # tmckay-fp again we can check the node group for the instance
-        # what are the implications for nova here? None, because use_namespaces
-        # is synonomous with use_neutron
-        # this is a test on whether access_instance has a floating_ip
+        # what are the implications for nova here? None.
+        # This is a test on whether access_instance has a floating_ip
         # in the neutron case, we check the node group for the
         # access_instance and look for fp
-        # in the nova case, we compare management_ip to internal_ip or even
-        # use the nova interface
         elif (CONF.use_namespaces and not net_utils.has_floating_ip(
                 access_instance)):
             # need neutron info
@@ -820,7 +820,7 @@ class InstanceInteropHelper(remote.Remote):
                 proxy_command, instance=access_instance, port=access_port,
                 info=info, rootwrap_command=rootwrap)
 
-        return _get_http_client(self.instance.management_ip, port,
+        return _get_http_client(_get_access_ip(self.instance), port,
                                 proxy_command, gateway_host,
                                 gateway_username,
                                 gateway_private_key)
@@ -828,7 +828,7 @@ class InstanceInteropHelper(remote.Remote):
     def close_http_session(self, port):
         global _sessions
 
-        host = self.instance.management_ip
+        host = _get_access_ip(self.instance)
         self._log_command(_("Closing HTTP session for %(host)s:%(port)s") % {
                           'host': host, 'port': port})
 
@@ -877,6 +877,10 @@ class InstanceInteropHelper(remote.Remote):
         return self._run_s(_read_file_from, timeout, description,
                            remote_file, run_as_root)
 
+    def get_python_version(self, timeout=None):
+        return self._run_s(
+            _get_python_to_execute, timeout, "get_python_version")
+
     def get_os_distrib(self, timeout=None):
         return self._run_s(_get_os_distrib, timeout, "get_os_distrib")
 
